@@ -1,7 +1,7 @@
 import numpy as np
 import pandas as pd
 import cv2
-import tools.visualization as visu
+import sgdot.tools.visualization as visu
 import copy
 
 # Imports for loading config files
@@ -32,7 +32,7 @@ class Grid:
             - a segment denoting which cluster the node belongs to
             - an allocation capacity, denoting how many households can be
               connected to the node.
- 
+
     _links : :class:`pandas.core.frame.DataFrame`
         Table containing all information related to the links
         between the nodes. The links are by definition undirected,
@@ -78,8 +78,8 @@ class Grid:
                                       }).set_index('label'),
                  _image_path='from_config_grid',
                  _meter_per_pixel_ratio=conf_grid.getfloat(
-                                                'files',
-                                                'meter_per_pixel_ratio'),
+                     'files',
+                     'meter_per_pixel_ratio'),
                  _path_config_files='./config/'):
         conf_grid.read(_path_config_files + 'conf_grid.cfg')
         if _id == 'from_config_grid':
@@ -95,7 +95,7 @@ class Grid:
         if _image_path is None:
             self._initial_image = np.ones((512, 512, 3), np.uint8) * 255
             self._image = visu.add_upper_margin(np.zeros((512, 512, 3),
-                                                np.uint8),
+                                                         np.uint8),
                                                 int(0.15 * 512))
         elif _image_path == 'from_config_grid':
             _image_path = conf_grid.get('files', 'village_image_path')
@@ -110,8 +110,8 @@ class Grid:
             self._initial_image = cv2.imread(_image_path)
         if _meter_per_pixel_ratio == 'from_config_grid':
             self._meter_per_pixel_ratio = conf_grid.getfloat(
-                                                'files',
-                                                'meter_per_pixel_ratio')
+                'files',
+                'meter_per_pixel_ratio')
         else:
             self._meter_per_pixel_ratio = _meter_per_pixel_ratio
         # Initial_image is the untouched image of the grid (used when plotting
@@ -303,10 +303,10 @@ class Grid:
         is_capacity_constraint_too_strong = False
         for segment in self.get_nodes()['segment'].unique():
             if self.get_households()[
-                    self.get_households()['segment'] == segment].shape[0] >\
-                        self.get_hubs()[
-                            self.get_hubs()['segment']
-                            == segment]['allocation_capacity'].sum():
+                self.get_households()['segment'] == segment].shape[0] >\
+                    self.get_hubs()[
+                    self.get_hubs()['segment']
+                    == segment]['allocation_capacity'].sum():
                 is_capacity_constraint_too_strong = True
 
         return is_capacity_constraint_too_strong
@@ -327,7 +327,7 @@ class Grid:
         """
 
         node_0 = self.get_nodes()[
-                            self.get_nodes()['segment'] == segment].index[0]
+            self.get_nodes()['segment'] == segment].index[0]
 
         nodes_in_spanning_tree = [node_0]
         loop_in_graph = False
@@ -335,10 +335,10 @@ class Grid:
         # find all neighbors of node_0
         neighbors_of_node_0 = []
         for index_neighbour in self.get_links()[(self.get_links()['from']
-                                                == node_0)]['to']:
+                                                 == node_0)]['to']:
             neighbors_of_node_0.append(index_neighbour)
         for index_neighbour in self.get_links()[(self.get_links()['to']
-                                                == node_0)]['from']:
+                                                 == node_0)]['from']:
             neighbors_of_node_0.append(index_neighbour)
 
         for neighbor in neighbors_of_node_0:
@@ -349,7 +349,7 @@ class Grid:
                                               node_0,
                                               neighbor)
         segment_size = self.get_nodes()[
-                            self.get_nodes()['segment'] == segment].shape[0]
+            self.get_nodes()['segment'] == segment].shape[0]
         return len(nodes_in_spanning_tree) == segment_size
 
     def loop_detection_iteration(self,
@@ -389,11 +389,11 @@ class Grid:
             nodes_in_spanning_tree.append(current_node)
             neighbors_of_current_nodes = []
             for index_neighbour in self.get_links()[(self.get_links()['from']
-                                                    == current_node)]['to']:
+                                                     == current_node)]['to']:
                 if index_neighbour != previous_node:
                     neighbors_of_current_nodes.append(index_neighbour)
             for index_neighbour in self.get_links()[(self.get_links()['to']
-                                                    == current_node)]['from']:
+                                                     == current_node)]['from']:
                 if index_neighbour != previous_node:
                     neighbors_of_current_nodes.append(index_neighbour)
 
@@ -544,8 +544,8 @@ class Grid:
         """
         self.clear_links()
         self._nodes = self._nodes.drop(
-                            [label for label in self._nodes.index],
-                            axis=0)
+            [label for label in self._nodes.index],
+            axis=0)
 
     def remove_outlier_nodes(self):
         """ Removes all nodes that are outside of the image (whose
@@ -560,9 +560,9 @@ class Grid:
             [label for label
              in self._nodes[
                  self._nodes['pixel_y_axis'] < (
-                                    self._image.shape[0]
-                                    - self._initial_image.shape[0])
-                 ].index],
+                     self._image.shape[0]
+                     - self._initial_image.shape[0])
+             ].index],
             axis=0)
         self._nodes = self._nodes.drop(
             [label for label
@@ -688,7 +688,7 @@ class Grid:
         """
 
         for label in self.get_non_fixed_nodes()[(self._nodes['node_type']
-                                                != 'powerhub')].index:
+                                                 != 'powerhub')].index:
             self.set_node_type(label, 'household')
 
     def set_all_node_type_to_meterhubs(self):
@@ -826,7 +826,7 @@ class Grid:
             and self._nodes[
                 'pixel_y_axis'][node] + delta_y <= self._image.shape[1]
             and self._nodes[
-               'pixel_y_axis'][node] + delta_y >= 0)
+                'pixel_y_axis'][node] + delta_y >= 0)
 
         if new_coord_within_boundary or allow_shifting_node_outside_boundary:
             # shift node
@@ -866,8 +866,8 @@ class Grid:
                                & (self._links['to']
                                   == label_node_to)].shape[0] >= 1:
             raise Warning('link (' + label_node_from + ', '
-                  + label_node_to + ') has not been added to the _links since '
-                  + 'it is already in the DataFrame')
+                          + label_node_to + ') has not been added to the _links since '
+                          + 'it is already in the DataFrame')
 
         # Make sure that the nodes are in the node dataframe and define
         # link type
@@ -876,7 +876,7 @@ class Grid:
             if (self._nodes['node_type'][label_node_from] == 'meterhub'
                 or self._nodes['node_type'][label_node_from] == 'powerhub')\
                and (self._nodes['node_type'][label_node_to] == 'meterhub'
-               or (self._nodes['node_type'][label_node_to] == 'powerhub')):
+                    or (self._nodes['node_type'][label_node_to] == 'powerhub')):
                 link_type = 'interhub'
             else:
                 link_type = 'distribution'
@@ -923,8 +923,8 @@ class Grid:
         """Removes all the links from the grid.
         """
         self._links = self.get_links().drop(
-                        [label for label in self.get_links().index],
-                        axis=0)
+            [label for label in self.get_links().index],
+            axis=0)
 
     def clear_interhub_links(self):
         """Removes all the interhub links from the grid$.
@@ -1019,9 +1019,9 @@ class Grid:
                 and label_node_2 in self._nodes.index:
             return self.get_meter_per_pixel_ratio()\
                 * np.sqrt((self._nodes["pixel_x_axis"][label_node_1]
-                          - (self._nodes["pixel_x_axis"][label_node_2])) ** 2
+                           - (self._nodes["pixel_x_axis"][label_node_2])) ** 2
                           + (self._nodes["pixel_y_axis"][label_node_1]
-                          - self._nodes["pixel_y_axis"][label_node_2]) ** 2)
+                             - self._nodes["pixel_y_axis"][label_node_2]) ** 2)
         else:
             return np.infty
 
