@@ -1,10 +1,7 @@
 import cv2
 import numpy as np
 import copy
-try:
-    import tools.optimization as opt
-except ModuleNotFoundError:
-    import optimization as opt
+import sgdot.tools.optimization as opt
 
 import matplotlib.pyplot as plt
 
@@ -329,7 +326,7 @@ def draw_all_nodes(grid):
                                   index,
                                   (int(row["pixel_x_axis"])
                                    - 10 - shift*(len(str(index))
-                                   - 1),
+                                                 - 1),
                                    int(row["pixel_y_axis"])+10),
                                   conf_cv2.getint('text', 'face'),
                                   conf_cv2.getint('text', 'node_font_size'),
@@ -526,13 +523,13 @@ def interactive_grid_plot(grid):
     conf_cv2 = ConfigParser()
     conf_cv2.read('./config/config_cv2.cfg')
 
-    #-------CREATE PRINCIPAL WINDOW CONTAINING THE PICTURE-------
+    # -------CREATE PRINCIPAL WINDOW CONTAINING THE PICTURE-------
     # Create principlal window containing the images.
     windowName = grid.get_id()
     cv2.namedWindow(windowName, cv2.WINDOW_FREERATIO)
 
-    #------CREATE SECONDAR WINDOW CONATINING THE TRACKBARS------
-    
+    # ------CREATE SECONDAR WINDOW CONATINING THE TRACKBARS------
+
     # Create second window containing the Trackbars/sliders.
     buttonWindow = 'buttonWindow'
     cv2.namedWindow(buttonWindow)
